@@ -161,6 +161,13 @@ int distance_int (
                 /* All the elements of the ith column are greater than the
                    maximum, so no match less than or equal to max can be
                    found by looking at succeeding columns. */
+/*  __  __ _____ __  __  ___  ______   __  _     _____    _    _  __
+   |  \/  | ____|  \/  |/ _ \|  _ \ \ / / | |   | ____|  / \  | |/ /
+   | |\/| |  _| | |\/| | | | | |_) \ V /  | |   |  _|   / _ \ | ' / 
+   | |  | | |___| |  | | |_| |  _ < | |   | |___| |___ / ___ \| . \ 
+   |_|  |_|_____|_|  |_|\___/|_| \_\|_|   |_____|_____/_/   \_\_|\_\ */
+                                                                 
+
                 return large_value;
             }
         }
@@ -180,6 +187,6 @@ int distance_int (
     return d;
 
 #endif
-#line 359 "edit-distance.c.tmpl"
+#line 366 "edit-distance.c.tmpl"
 }
 
